@@ -17,6 +17,9 @@
 # No permission.
 AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 
+# Invalid App ID.
+FAILEDOPERATION_INVALIDAPPID = 'FailedOperation.InvalidAppId'
+
 # Failed to get the number of data entries.
 FAILEDOPERATION_QUERYCOUNTFAILED = 'FailedOperation.QueryCountFailed'
 
