@@ -229,6 +229,35 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateOIDCConfig(self, request):
+        """This API is used to create role OIDC configurations.
+
+        :param request: Request instance for CreateOIDCConfig.
+        :type request: :class:`tencentcloud.cam.v20190116.models.CreateOIDCConfigRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.CreateOIDCConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateOIDCConfig", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateOIDCConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreatePolicy(self, request):
         """This API (CreatePolicy) is used to create a policy.
 
@@ -461,6 +490,35 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteOIDCConfig(self, request):
+        """This API is used to delete OIDC IdPs.
+
+        :param request: Request instance for DeleteOIDCConfig.
+        :type request: :class:`tencentcloud.cam.v20190116.models.DeleteOIDCConfigRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.DeleteOIDCConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteOIDCConfig", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteOIDCConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeletePolicy(self, request):
         """This API (DeletePolicy) is used to delete a policy.
 
@@ -693,6 +751,35 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeOIDCConfig(self, request):
+        """This API is used to query role OIDC configurations.
+
+        :param request: Request instance for DescribeOIDCConfig.
+        :type request: :class:`tencentcloud.cam.v20190116.models.DescribeOIDCConfigRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.DescribeOIDCConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOIDCConfig", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeOIDCConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRoleList(self, request):
         """This API (DescribeRoleList) is used to get the role list under the account.
 
@@ -1911,6 +1998,35 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateOIDCConfig(self, request):
+        """This API is used to modify role OIDC configurations.
+
+        :param request: Request instance for UpdateOIDCConfig.
+        :type request: :class:`tencentcloud.cam.v20190116.models.UpdateOIDCConfigRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.UpdateOIDCConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateOIDCConfig", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateOIDCConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdatePolicy(self, request):
         """This API is used to update a policy.
         This API will update the default version of an existing policy instead of creating a new one. If no policy exists, a default version will be created.
