@@ -35,6 +35,9 @@ FAILEDOPERATION_POLICYVERSIONALREADYDEFAULT = 'FailedOperation.PolicyVersionAlre
 # The number of policy versions has reached the upper limit.
 FAILEDOPERATION_POLICYVERSIONFULL = 'FailedOperation.PolicyVersionFull'
 
+# 
+FAILEDOPERATION_TAGRESOURCEFAILED = 'FailedOperation.TagResourceFailed'
+
 # No mobile number is bound to the account
 FAILEDOPERATION_USERNOTBINDPHONE = 'FailedOperation.UserNotBindPhone'
 
@@ -209,6 +212,12 @@ INVALIDPARAMETER_SUBUSERFULL = 'InvalidParameter.SubUserFull'
 # Sub-user name repeated.
 INVALIDPARAMETER_SUBUSERNAMEINUSE = 'InvalidParameter.SubUserNameInUse'
 
+# 
+INVALIDPARAMETER_TAGLIMITEXCEEDED = 'InvalidParameter.TagLimitExceeded'
+
+# 
+INVALIDPARAMETER_TAGPARAMERROR = 'InvalidParameter.TagParamError'
+
 # `Uin` field invalid.
 INVALIDPARAMETER_UINERROR = 'InvalidParameter.UinError'
 
