@@ -316,6 +316,35 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteRoute(self, request):
+        """This API is used to delete a route.
+
+        :param request: Request instance for DeleteRoute.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DeleteRouteRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DeleteRouteResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteRoute", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteRouteResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteRouteTriggerTime(self, request):
         """This API is used to modify the delayed trigger time of route deletion.
 
